@@ -2,18 +2,17 @@ package Catalyst::Plugin::Authentication;
 
 use base qw/Class::Accessor::Fast Class::Data::Inheritable/;
 
-BEGIN {
-    __PACKAGE__->mk_accessors(qw/_user/);
-}
+__PACKAGE__->mk_accessors(qw/_user/);
 
 use strict;
 use warnings;
 
+use MRO::Compat;
 use Tie::RefHash;
 use Class::Inspector;
 use Catalyst::Authentication::Realm;
 
-our $VERSION = "0.100092";
+our $VERSION = "0.10010";
 
 sub set_authenticated {
     my ( $c, $user, $realmname ) = @_;
@@ -34,7 +33,7 @@ sub set_authenticated {
 
     $c->persist_user();    
     
-    $c->NEXT::set_authenticated($user, $realmname);
+    $c->maybe::next::method($user, $realmname);
 }
 
 sub user {
@@ -132,7 +131,7 @@ sub logout {
         $realm->remove_persisted_user($c);
     }
     
-    $c->NEXT::logout(@_);
+    $c->maybe::next::method(@_);
 }
 
 sub find_user {
@@ -189,7 +188,7 @@ sub auth_restore_user {
     $c->_user( my $user = $realm->restore_user( $c, $frozen_user ) );
     
     # this sets the realm the user originated in.
-    $user->auth_realm($realm->name);
+    $user->auth_realm($realm->name) if $user;
         
     return $user;
 
@@ -201,7 +200,7 @@ sub setup {
     my $app = shift;
 
     $app->_authentication_initialize();
-    $app->NEXT::setup(@_);
+    $app->next::method(@_);
 }
 
 ## the actual initialization routine. whee.
